pub struct ExtrasSpecification(/* private fields */);Expand description
Manager of all extra decisions and settings history.
This is an Arc mostly just to avoid size bloat on things that contain these.
Implementations
Sourceimpl ExtrasSpecification
impl ExtrasSpecification
Sourcepub fn from_args(
extra: Vec<ExtraName>,
no_extra: Vec<ExtraName>,
no_default_extras: bool,
only_extra: Vec<ExtraName>,
all_extras: bool,
) -> Self
pub fn from_args( extra: Vec<ExtraName>, no_extra: Vec<ExtraName>, no_default_extras: bool, only_extra: Vec<ExtraName>, all_extras: bool, ) -> Self
Create from raw CLI args
Sourcepub fn from_extra(extra: Vec<ExtraName>) -> Self
pub fn from_extra(extra: Vec<ExtraName>) -> Self
Helper to make a spec from just a –extra
Sourcepub fn from_all_extras() -> Self
pub fn from_all_extras() -> Self
Helper to make a spec from just –all-extras
Sourcepub fn with_defaults(
&self,
defaults: DefaultExtras,
) -> ExtrasSpecificationWithDefaults
pub fn with_defaults( &self, defaults: DefaultExtras, ) -> ExtrasSpecificationWithDefaults
Apply defaults to a base ExtrasSpecification.
Methods from Deref<Target = ExtrasSpecificationInner>
Sourcepub fn contains(&self, extra: &ExtraName) -> bool
pub fn contains(&self, extra: &ExtraName) -> bool
Returns true if the specification includes the given extra.
Sourcepub fn extra_names<'a, Names>(
&'a self,
all_names: Names,
) -> impl Iterator<Item = &'a ExtraName> + 'a
pub fn extra_names<'a, Names>( &'a self, all_names: Names, ) -> impl Iterator<Item = &'a ExtraName> + 'a
Returns an iterator over all extras that are included in the specification,
assuming all_names is an iterator over all extras.
Sourcepub fn explicit_names(&self) -> impl Iterator<Item = &ExtraName>
pub fn explicit_names(&self) -> impl Iterator<Item = &ExtraName>
Iterate over all groups the user explicitly asked for on the CLI
Sourcepub fn history(&self) -> &ExtrasSpecificationHistory
pub fn history(&self) -> &ExtrasSpecificationHistory
Get the raw history for diagnostics